==> wrapper_3.4.1_src.zip: wrapper_3.4.1_src/src/java/org/tanukisoftware/wrapper/event/WrapperLoggingEvent.java <==
package org.tanukisoftware.wrapper.event;

/*
 * Copyright (c) 1999, 2010 Tanuki Software, Ltd.
 * http://www.tanukisoftware.com
 * All rights reserved.
 *
 * This software is the proprietary information of Tanuki Software.
 * You shall use it only in accordance with the terms of the
 * license agreement you entered into with Tanuki Software.
 * http://wrapper.tanukisoftware.org/doc/english/licenseOverview.html
 */

/**
 * WrapperLoggingEvents are used to notify the listener of events related
 *  to logging such as updates to the log file name.
 *
 * @author Leif Mortenson <leif@tanukisoftware.com>
 */
public abstract class WrapperLoggingEvent
    extends WrapperEvent
{
    /*---------------------------------------------------------------
     * Constructors
     *-------------------------------------------------------------*/
    /**
     * Creates a new WrapperLoggingEvent.
     */
    protected WrapperLoggingEvent()
    {
    }
    
    /*---------------------------------------------------------------
     * WrapperLoggingEvent Methods
     *-------------------------------------------------------------*/
    /**
     * Returns a set of event flags for which the event should be fired.
     *  This value is compared with the mask supplied when when a
     *  WrapperEventListener is registered to decide which listeners should
     *  receive the event.
     * <p>
     * If a subclassed, the return value of the super class should usually
     *  be ORed with any additional flags.
     *
     * @return a set of event flags.
     */
    public long getFlags()
    {
        return super.getFlags() | WrapperEventListener.EVENT_FLAG_LOGGING;
    }
}

==> wrapper_3.5.0_src.zip: wrapper_3.5.0_src/src/java/org/tanukisoftware/wrapper/event/WrapperLoggingEvent.java <==
package org.tanukisoftware.wrapper.event;

/*
 * Copyright (c) 1999, 2010 Tanuki Software, Ltd.
 * http://www.tanukisoftware.com
 * All rights reserved.
 *
 * This software is the proprietary information of Tanuki Software.
 * You shall use it only in accordance with the terms of the
 * license agreement you entered into with Tanuki Software.
 * http://wrapper.tanukisoftware.com/doc/english/licenseOverview.html
 */

/**
 * WrapperLoggingEvents are used to notify the listener of events related
 *  to logging such as updates to the log file name.
 *
 * @author Leif Mortenson <leif@tanukisoftware.com>
 */
public abstract class WrapperLoggingEvent
    extends WrapperEvent
{
    /*---------------------------------------------------------------
     * Constructors
     *-------------------------------------------------------------*/
    /**
     * Creates a new WrapperLoggingEvent.
     */
    protected WrapperLoggingEvent()
    {
    }
    
    /*---------------------------------------------------------------
     * WrapperLoggingEvent Methods
     *-------------------------------------------------------------*/
    /**
     * Returns a set of event flags for which the event should be fired.
     *  This value is compared with the mask supplied when when a
     *  WrapperEventListener is registered to decide which listeners should
     *  receive the event.
     * <p>
     * If subclassed, the return value of the super class should usually
     *  be ORed with any additional flags.
     *
     * @return a set of event flags.
     */
    public long getFlags()
    {
        return super.getFlags() | WrapperEventListener.EVENT_FLAG_LOGGING;
    }
}
